/**
 * lint commit message
 *
 * 基础格式：
 * type(scope?): subject
 * 注意：scope范围可选，冒号后面有空格，tapd有对应需求或缺陷时subject需要包含--story|bug=\d+
 *
 * 例子：
 * feat(doc): --story=10086 add comment section
 * fix: 处理一周精选乱序问题 --bug=123456
 */
module.exports = {
  extends: [
    '@commitlint/config-conventional',
  ],
  plugins: ['@lexiang/commitlint-plugin-subject'],
  rules: {
    'header-max-length': [1, 'always', 72],
    'type-case': [1, 'always', 'lower-case'],
    'type-empty': [2, 'never'],
    'type-enum': [
      1, 'always', [
        'build', // 构建
        'chore', // 辅助工具、依赖
        'ci', // 持续集成
        'docs', // 文档修改
        'feat', // 新功能
        'fix', // 缺陷修复
        'init', // 初始化
        'merge', // 分支合并
        'perf', // 性能
        'publish', // 发布
        'refactor', // 重构
        'revert', // 回退
        'style', // 代码格式化
        'test', // 测试
      ],
    ],
    'scope-case': [1, 'always', 'lower-case'],
    'subject-case': [0, 'never'],
    'subject-empty': [2, 'never'],
    'subject-full-stop': [0, 'never'],
    'subject-regexp': [1, 'always', /--bug|story=\d+/],
  },
};
